#!/bin/sh
# merge_cond.sh -- conditional merge script
# Findmerge is run 1st (in foreground) to determine if a merge is needed,
# if so, a background process is started to do the merge, if not, the
# user is informed via a non=blocking pop-up.
#
# $1 is the 'to' version
# $2 is the 'from' clause, e.g. '-flatest' or '-fver /main/10'
# $3 is the pathname of the terminal emulator script
#
TERM_EM="$3"

TMP="/tmp/merge.$$"
if cleartool findmerge "$1" $2 -whynot -print -log /dev/null >$TMP ; then
    # No errors
    if  grep "Needs Merge" $TMP >/dev/null ; then
	# Needs merge
	clearprompt yes_no -default yes -prefer_gui -prompt \
	"Merge can try a totally automatic (non-graphic) merge first.
If human intervention is needed due to a merge conflict the
merge will be stopped and graphical merge tool will be invoked.

Try automatic merge first?"

	st=$?
	if [ $st = 2 ] ; then
	    rm -f $TMP
	    exit 1
	elif [ $st = 0 ] ; then
	    # yes, do a -merge -gmerge
	    $TERM_EM NO_MORE "cleartool findmerge \"$1\" $2 -merge -gmerge -whynot -log /dev/null"
	else
	    # no, plain -gmerge
	    # Ask about -qall option
	    clearprompt yes_no -default yes -prefer_gui -prompt \
	    "The graphical merge tool can automatically make decisions
about non-conflicting differences or it can require you to
make each decision.  Do you wish to allow the merge tool
to automatically decide for all non-conflicting differences?"

	    st=$?
	    if [ $st = 2 ] ; then
		rm -f $TMP
		exit 1
	    elif [ $st = 0 ] ; then
		# yes, don't use -qall
	        cleartool findmerge "$1" $2 -gmerge -whynot -log /dev/null &
	    else
		# user wants to query all
		cleartool findmerge "$1" $2 -qall -gmerge -whynot -log \
						/dev/null &
		fi
	fi
	exit 0
    else
	# Doesn't need merge
	(clearprompt proceed -mask proceed \
		-type warning -prompt "`cat $TMP`" -prefer_gui
	rm -f $TMP ) &
	exit 0
    fi
else
   # Error
   rm -f $TMP
   exit 1
fi
